# Generated by Django 4.2.16 on 2025-05-07 01:35

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0024_productaddonsummary_key"),
    ]

    operations = [
        migrations.AddField(
            model_name="subscriptionsummary",
            name="original_billing_date",
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="subscriptionsummary",
            name="original_plan",
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
        migrations.AddField(
            model_name="subscriptionsummary",
            name="original_signing_date",
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="subscriptionsummary",
            name="original_total_contract_price",
            field=models.DecimalField(
                blank=True, decimal_places=2, max_digits=10, null=True
            ),
        ),
        migrations.AddField(
            model_name="subscriptionsummary",
            name="original_total_contracted_staff_licenses",
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
