# Generated by Django 4.2.16 on 2025-03-04 04:31

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0019_usersummaryrow_addons"),
    ]

    operations = [
        migrations.CreateModel(
            name="LatestUsageMetrics",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("workspace", models.CharField(max_length=200)),
                ("account_number", models.CharField(max_length=50)),
                ("subscription_currency", models.CharField(max_length=3)),
                ("month_start", models.DateField()),
                ("dimension", models.CharField(max_length=200)),
                ("value", models.BigIntegerField()),
                ("as_of", models.DateTimeField()),
            ],
            options={
                "db_table": 'workforce"."mv_usage_metrics_latest',
                "managed": True,
            },
        ),
        migrations.AddConstraint(
            model_name="latestusagemetrics",
            constraint=models.UniqueConstraint(
                fields=("workspace", "dimension", "month_start"),
                name="idx_mvusagemetricslatest",
            ),
        ),
    ]
