# Generated by Django 4.2.16 on 2025-05-02 18:33

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "subscriptionmanager",
            "0022_delete_accountcodemap_delete_groupaccountcategory",
        ),
    ]

    operations = [
        migrations.CreateModel(
            name="ProductAddonSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField()),
                ("name", models.CharField(max_length=100)),
                ("is_usage_based", models.BooleanField(default=True)),
                (
                    "price_aud",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_nzd",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_gbp",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_cad",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_usd",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_eur",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                ("is_current", models.BooleanField(default=True)),
            ],
            options={
                "db_table": 'subscriptionmanager"."product_addon_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
    ]
