# Generated by Django 3.2.16 on 2024-03-22 05:53

from decimal import Decimal

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0004_auto_20231009_1407"),
    ]

    operations = [
        migrations.CreateModel(
            name="ConsolidatedProfitAndLossMonth",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField()),
                ("entity_name", models.CharField(max_length=200)),
                ("date", models.DateField()),
                ("local_account_code", models.CharField(max_length=100)),
                ("local_account_name", models.CharField(max_length=300)),
                ("local_account_category", models.CharField(max_length=300)),
                ("group_account_code", models.CharField(max_length=100)),
                ("group_account_name", models.CharField(max_length=300)),
                (
                    "subtotal",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                ("currency", models.CharField(max_length=3)),
                (
                    "reporting_fx_rate",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                (
                    "reporting_subtotal",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                ("reporting_region", models.CharField(max_length=200)),
            ],
            options={
                "db_table": 'subscriptionmanager"."consolidated_profit_and_loss_month',
                "managed": True,
                "default_permissions": (),
            },
        ),
    ]
