# Generated by Django 4.2.16 on 2025-07-03 14:14

import datetime

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0029_invoicelineitemsummary"),
    ]

    operations = [
        migrations.AlterField(
            model_name="subscriptionsummary",
            name="original_billing_date",
            field=models.DateField(blank=True, default=datetime.date(1900, 1, 1)),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="subscriptionsummary",
            name="original_signing_date",
            field=models.DateField(blank=True, default=datetime.date(1900, 1, 1)),
            preserve_default=False,
        ),
    ]
