# Generated by Django 3.2.16 on 2024-07-11 00:31

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0010_auto_20240623_2142"),
    ]

    operations = [
        migrations.AddField(
            model_name="subscriptionsummary",
            name="deal_originator",
            field=models.CharField(max_length=200, null=True),
        ),
    ]
