# Generated by Django 4.2.16 on 2025-07-01 07:17

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0026_rollforwardsummary_product_expansion_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="xeroinvoicesummary",
            name="reference",
            field=models.CharField(max_length=100, null=True, blank=True),
        ),
    ]
