# Generated by Django 4.2.16 on 2024-09-07 11:59

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("mixpanel", "0002_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="mixpanelusercohort",
            name="cohort_name",
            field=models.CharField(
                db_index=True,
                default="",
                help_text="Cohort name from Mixpanel",
                max_length=150,
            ),
        ),
    ]
