# Generated by Django 4.2.16 on 2025-07-02 01:02

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0028_fixedfxrate"),
    ]

    operations = [
        migrations.CreateModel(
            name="InvoiceLineItemSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField(null=True)),
                ("customer_account_number", models.CharField(max_length=25)),
                ("account_code", models.CharField(max_length=20)),
                ("key", models.CharField(blank=True, max_length=100, null=True)),
                ("currency", models.CharField(max_length=3)),
                ("quantity", models.DecimalField(decimal_places=2, max_digits=10)),
                ("amount", models.DecimalField(decimal_places=2, max_digits=10)),
                (
                    "discount",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=5, null=True
                    ),
                ),
                ("tax_rate", models.CharField(max_length=20)),
                ("subtotal", models.DecimalField(decimal_places=2, max_digits=10)),
                ("total", models.DecimalField(decimal_places=2, max_digits=10)),
            ],
            options={
                "db_table": 'subscriptionmanager"."invoice_line_item_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
    ]
