# Generated by Django 3.2.16 on 2023-10-09 14:07

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0003_auto_20230123_0443"),
    ]

    operations = [
        migrations.AddField(
            model_name="revenueforecastsummary",
            name="downgrades_book",
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name="revenueforecastsummary",
            name="downgrades_contract",
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name="revenueforecastsummary",
            name="loss_value",
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name="revenueforecastsummary",
            name="new_paying_value",
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name="revenueforecastsummary",
            name="total_contract_paying_value",
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name="revenueforecastsummary",
            name="upgrades_book",
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name="revenueforecastsummary",
            name="upgrades_contract",
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
    ]
