# Generated by Django 4.2.16 on 2025-01-04 00:09

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0018_fix_routine_usage_metrics"),
    ]

    operations = [
        migrations.AddField(
            model_name="usersummaryrow",
            name="addons",
            field=django.contrib.postgres.fields.ArrayField(
                base_field=models.CharField(max_length=150),
                blank=True,
                default=list,
                size=None,
            ),
        ),
    ]
