# Generated by Django 4.2.16 on 2025-04-16 01:13

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0021_addonsummary_price_eur_plansummary_price_eur"),
    ]

    operations = [
        migrations.DeleteModel(
            name="AccountCodeMap",
        ),
        migrations.DeleteModel(
            name="GroupAccountCategory",
        ),
    ]
