# Generated by Django 4.2.16 on 2025-05-15 05:41

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0022_serverusagedata"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="serverusagedata",
            name="as_at",
        ),
        migrations.AddField(
            model_name="serverusagedata",
            name="as_of",
            field=models.DateTimeField(default=django.utils.timezone.now),
            preserve_default=False,
        ),
    ]
