# Generated by Django 3.2.16 on 2023-10-05 10:26

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0007_auto_20230704_2306"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="constancesetting",
            name="last_reported",
        ),
    ]
