# Generated by Django 4.2.16 on 2024-10-08 00:26

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0013_rollforwardsummary"),
    ]

    operations = [
        migrations.AddField(
            model_name="subscriptionsummary",
            name="primary_termination_reason",
            field=models.CharField(blank=True, max_length=25),
        ),
    ]
