# Generated by Django 4.2.16 on 2025-07-08 09:46

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0030_alter_subscription_originals"),
    ]

    operations = [
        migrations.AddField(
            model_name="productaddonsummary",
            name="billing_unit_description",
            field=models.CharField(blank=True, default="", max_length=100),
        ),
        migrations.AddField(
            model_name="productaddonsummary",
            name="description",
            field=models.CharField(blank=True, default="", max_length=200),
        ),
    ]
