# Generated by Django 4.2.16 on 2024-09-27 06:31

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0015_auto_20240926_0155"),
    ]

    operations = [
        migrations.CreateModel(
            name="BenchmarkDataPoint",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("tenant", models.CharField(db_index=True, max_length=200)),
                ("country", models.CharField(db_index=True, max_length=200)),
                ("timestamp", models.DateField(db_index=True)),
                ("benchmark_type", models.CharField(db_index=True, max_length=200)),
                ("value", models.DecimalField(decimal_places=2, max_digits=20)),
            ],
            options={
                "db_table": 'workforce"."benchmarks',
                "managed": True,
                "default_permissions": (),
                "unique_together": {("tenant", "benchmark_type", "timestamp")},
            },
        ),
    ]
