# Generated by Django 3.2.16 on 2024-01-16 23:39

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0010_alter_usagemetrics_for_date"),
    ]

    operations = [
        migrations.CreateModel(
            name="SyncedData",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("tenant", models.CharField(db_index=True, max_length=200)),
                ("key", models.CharField(db_index=True, max_length=200)),
                ("data", models.JSONField()),
                ("last_synced", models.DateTimeField(db_index=True, null=True)),
            ],
            options={
                "db_table": 'workforce"."synced_data',
                "managed": True,
                "default_permissions": (),
                "unique_together": {("tenant", "key")},
            },
        ),
    ]
