# Generated by Django 4.2.16 on 2025-05-15 01:16

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0021_delete_onboardingactionrow_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="ServerUsageData",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("workspace", models.CharField(db_index=True, max_length=50)),
                ("for_date", models.DateField(db_index=True)),
                ("as_at", models.DateField()),
                ("usage_key", models.CharField(db_index=True, max_length=100)),
                ("amount", models.IntegerField(default=0)),
                ("data", models.JSONField(blank=True, null=True)),
            ],
            options={
                "db_table": 'workforce"."server_usage_data',
                "managed": True,
                "default_permissions": (),
                "unique_together": {("workspace", "for_date", "usage_key")},
            },
        ),
    ]
