# Generated by Django 3.2.16 on 2024-07-24 04:36

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0011_subscriptionsummary_customer_address"),
        ("subscriptionmanager", "0011_subscriptionsummary_deal_originator"),
    ]

    operations = []
