# Generated by Django 4.2.16 on 2025-02-14 22:21

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("hubspot", "0001_schema"),
    ]

    operations = [
        migrations.CreateModel(
            name="CustomerContacts",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=255)),
                ("email", models.CharField(max_length=200)),
                ("tenant", models.CharField(db_index=True, max_length=200)),
                ("license", models.CharField(db_index=True, max_length=10)),
                (
                    "groups",
                    django.contrib.postgres.fields.ArrayField(
                        base_field=models.CharField(max_length=150),
                        blank=True,
                        default=list,
                        size=None,
                    ),
                ),
                ("currency", models.CharField(max_length=3)),
            ],
            options={
                "db_table": 'hubspot"."customer_contacts',
                "managed": False,
                "default_permissions": (),
            },
        ),
    ]
