# Generated by Django 4.2.16 on 2024-10-03 05:23

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0016_benchmarkdatapoint"),
    ]

    operations = [
        migrations.CreateModel(
            name="Benchmark",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("count_name", models.CharField(max_length=200)),
                ("country_cohort", models.CharField(max_length=200)),
                ("size_cohort", models.CharField(max_length=20)),
                ("industry_cohort", models.CharField(max_length=20)),
                ("value", models.DecimalField(decimal_places=2, max_digits=20)),
                ("tenant_count", models.IntegerField()),
            ],
            options={
                "db_table": 'workforce"."usage_metrics_benchmarks',
                "managed": False,
                "default_permissions": (),
            },
        ),
        migrations.DeleteModel(
            name="BenchmarkDataPoint",
        ),
    ]
