# Generated by Django 4.2.16 on 2024-09-07 10:51

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("mixpanel", "0001_schema"),
    ]

    operations = [
        migrations.CreateModel(
            name="MixpanelUserCohort",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField(auto_now_add=True)),
                (
                    "user_slug",
                    models.TextField(
                        db_index=True,
                        help_text="User's unique identifier eg: arafire_321",
                    ),
                ),
                (
                    "cohort_name",
                    models.TextField(
                        db_index=True, default="", help_text="Cohort name from Mixpanel"
                    ),
                ),
                (
                    "cohort_id",
                    models.TextField(
                        db_index=True, default="", help_text="Cohort ID from Mixpanel"
                    ),
                ),
            ],
            options={
                "db_table": 'mixpanel"."mixpanel_user_cohort',
                "managed": True,
                "default_permissions": (),
                "unique_together": {("user_slug", "cohort_id")},
            },
        ),
    ]
