# Generated by Django 3.2.16 on 2023-02-05 23:37

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0002_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="serverusage",
            name="contractor_addons_used",
            field=models.IntegerField(default=0),
        ),
    ]
