# Generated by Django 3.2.16 on 2024-09-26 01:55

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0014_alter_synceddata_data"),
    ]

    operations = [
        migrations.AddField(
            model_name="serverusage",
            name="premium_portal_buildings",
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name="serverusage",
            name="premium_portal_tenancies",
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name="serverusage",
            name="sms_notifications",
            field=models.IntegerField(default=0),
        ),
    ]
