# Generated by Django 4.2.16 on 2024-12-12 23:49

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0014_subscriptionsummary_primary_termination_reason"),
    ]

    operations = [
        migrations.CreateModel(
            name="Workspace",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=30)),
                ("customer", models.CharField(max_length=30)),
                ("cluster", models.CharField()),
                ("account_number", models.CharField(max_length=25, null=True)),
                (
                    "tags",
                    django.contrib.postgres.fields.ArrayField(
                        base_field=models.CharField(), null=True, size=None
                    ),
                ),
            ],
            options={
                "db_table": 'subscriptionmanager"."workspace',
                "managed": True,
                "default_permissions": (),
            },
        ),
    ]
