# Generated by Django 4.2.16 on 2025-03-23 04:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0019_groupaccountcategory"),
    ]

    operations = [
        migrations.AddField(
            model_name="rollforwardsummary",
            name="customer_group_code",
            field=models.CharField(default="", max_length=50),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="subscriptionsummary",
            name="customer_group_code",
            field=models.CharField(db_index=True, default="", max_length=50),
            preserve_default=False,
        ),
    ]
