# Generated by Django 4.2.16 on 2025-01-04 00:57

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0015_workspace"),
    ]

    operations = [
        migrations.AlterField(
            model_name="workspace",
            name="name",
            field=models.CharField(max_length=30, unique=True),
        ),
        migrations.AlterField(
            model_name="workspace",
            name="tags",
            field=django.contrib.postgres.fields.ArrayField(
                base_field=models.CharField(), default=list, size=None
            ),
        ),
        migrations.AddIndex(
            model_name="workspace",
            index=models.Index(fields=["cluster"], name="workspace_cluster_3a614d_idx"),
        ),
    ]
