# Generated by Django 4.2.16 on 2025-06-04 01:49
from decimal import Decimal

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "subscriptionmanager",
            "0025_subscriptionsummary_original_billing_date_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="rollforwardsummary",
            name="product_expansion",
            field=models.DecimalField(
                decimal_places=2, default=Decimal("0.00"), max_digits=10
            ),
        ),
        migrations.AddField(
            model_name="rollforwardsummary",
            name="product_expansion_mom",
            field=models.DecimalField(
                decimal_places=2, default=Decimal("0.00"), max_digits=10
            ),
        ),
    ]
