# Generated by Django 3.2.16 on 2023-06-06 06:58

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0004_customreportsummary"),
    ]

    operations = [
        migrations.AddField(
            model_name="constancesetting",
            name="last_synced",
            field=models.DateTimeField(null=True),
        ),
        migrations.AddField(
            model_name="extensionsummary",
            name="last_synced",
            field=models.DateTimeField(null=True),
        ),
        migrations.AddField(
            model_name="featureflagsummary",
            name="last_synced",
            field=models.DateTimeField(null=True),
        ),
        migrations.AddField(
            model_name="templatechangerequestsummary",
            name="last_synced",
            field=models.DateTimeField(null=True),
        ),
    ]
