# Generated by Django 4.2.16 on 2025-09-05 00:49

from decimal import Decimal

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0032_rollforwardsummary_pass_through_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="rollforwardsummary",
            name="price_increase_upgrade_or_downgrade",
            field=models.DecimalField(
                decimal_places=2, default=Decimal("0.00"), max_digits=10
            ),
        ),
    ]
