# Generated by Django 4.2.16 on 2025-05-02 19:44

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0023_productaddonsummary"),
    ]

    operations = [
        migrations.AddField(
            model_name="productaddonsummary",
            name="key",
            field=models.CharField(default="", max_length=100),
            preserve_default=False,
        ),
    ]
