# Generated by Django 3.2.16 on 2024-01-17 00:29

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0012_auto_20240117_0012"),
    ]

    operations = [
        migrations.RenameField(
            model_name="synceddata",
            old_name="oauth_state",
            new_name="data",
        ),
    ]
