# Generated by Django 4.2.16 on 2025-02-12 21:35

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "subscriptionmanager",
            "0016_alter_workspace_name_alter_workspace_tags_and_more",
        ),
    ]

    operations = [
        migrations.CreateModel(
            name="AccountCodeMap",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("entity_name", models.CharField(max_length=200)),
                ("local_account_name", models.CharField(max_length=200)),
                ("group_account_name", models.CharField(max_length=200)),
                ("last_synced", models.DateTimeField(db_index=True)),
            ],
            options={
                "db_table": 'subscriptionmanager"."account_code_map',
                "managed": True,
                "default_permissions": (),
            },
        ),
    ]
