# Generated by Django 4.2.16 on 2025-04-06 05:46

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0020_rollforwardsummary_customer_group_code_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="addonsummary",
            name="price_eur",
            field=models.DecimalField(
                blank=True, decimal_places=2, max_digits=10, null=True
            ),
        ),
        migrations.AddField(
            model_name="plansummary",
            name="price_eur",
            field=models.DecimalField(
                blank=True, decimal_places=2, max_digits=10, null=True
            ),
        ),
    ]
