# Generated by Django 4.2.16 on 2025-04-10 02:05

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0020_materialiezdusagemetrics"),
    ]

    operations = [
        migrations.DeleteModel(
            name="OnboardingActionRow",
        ),
        migrations.DeleteModel(
            name="TemplateChangeRequestSummary",
        ),
    ]
