# Generated by Django 3.2.16 on 2024-05-16 02:57

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0006_alter_reporting_fx_rate_2024_04_15"),
    ]

    operations = [
        migrations.CreateModel(
            name="AddonSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=100)),
                ("category", models.CharField(blank=True, max_length=100)),
                ("equivalent", models.CharField(blank=True, max_length=100)),
                ("metered_value", models.CharField(max_length=50)),
                (
                    "price_aud",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_nzd",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_gbp",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_cad",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_usd",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                ("is_current", models.BooleanField(default=True)),
            ],
            options={
                "db_table": 'subscriptionmanager"."billing_addon_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="PlanSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=100)),
                ("category", models.CharField(blank=True, max_length=100)),
                ("equivalent", models.CharField(blank=True, max_length=100)),
                ("included_users", models.IntegerField()),
                (
                    "price_aud",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_nzd",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_gbp",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_cad",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_usd",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "recommended_addon_name",
                    models.CharField(blank=True, max_length=100),
                ),
                ("is_current", models.BooleanField(default=True)),
                ("expects_licensing_usage", models.BooleanField(default=True)),
            ],
            options={
                "db_table": 'subscriptionmanager"."billing_plan_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
        migrations.AddField(
            model_name="subscriptionsummary",
            name="termination_notification_date",
            field=models.DateField(blank=True, null=True),
        ),
    ]
