# Generated by Django 4.2.16 on 2025-07-01 08:25

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0027_alter_xeroinvoicesummary_reference"),
    ]

    operations = [
        migrations.CreateModel(
            name="FixedFXRate",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("currency", models.CharField(max_length=3)),
                ("rate", models.DecimalField(decimal_places=4, max_digits=10)),
                ("applicable_from", models.DateField(blank=True, null=True)),
                ("applicable_to", models.DateField(blank=True, null=True)),
            ],
            options={
                "db_table": 'subscriptionmanager"."fixed_fx_rate',
                "managed": True,
                "default_permissions": (),
            },
        ),
    ]
